Struct
QmiMessageWmsRawWriteOutput
since: 1.0
Description [src]
struct QmiMessageWmsRawWriteOutput {
/* No available fields */
}
The QmiMessageWmsRawWriteOutput structure contains private data and should only be accessed
using the provided API.
Available since: 1.0
Instance methods
qmi_message_wms_raw_write_output_get_memory_index
Get the ‘Memory Index’ field from self.
since: 1.0
qmi_message_wms_raw_write_output_ref
Atomically increments the reference count of self by one.
since: 1.0
qmi_message_wms_raw_write_output_unref
Atomically decrements the reference count of self by one.
If the reference count drops to 0, self is completely disposed.
since: 1.0